SparsePCA
=========

.. currentmodule:: xeofs.single

.. autoclass:: SparsePCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SparsePCA.__init__
      ~SparsePCA.components
      ~SparsePCA.compute
      ~SparsePCA.deserialize
      ~SparsePCA.explained_variance
      ~SparsePCA.explained_variance_ratio
      ~SparsePCA.fit
      ~SparsePCA.fit_transform
      ~SparsePCA.get_params
      ~SparsePCA.get_serialization_attrs
      ~SparsePCA.inverse_transform
      ~SparsePCA.load
      ~SparsePCA.save
      ~SparsePCA.scores
      ~SparsePCA.serialize
      ~SparsePCA.transform
   
   

   
   
   